@@ -1,17 +1,13 @@
 import sys
 import warnings
+from collections.abc import Iterator, Mapping
 from contextlib import contextmanager, suppress
 from typing import (
     TYPE_CHECKING,
     Any,
     Callable,
     ClassVar,
-    Dict,
-    Iterator,
-    Mapping,
     NamedTuple,
-    Set,
-    Type,
     Union,
     cast,
     no_type_check,
@@ -32,6 +28,8 @@ if TYPE_CHECKING:
     from pydantic import ConfigDict
     from pydantic._internal import _model_construction as pydantic_main
     from pydantic._internal import _utils as utils
+    from pydantic._internal._decorators import PydanticDescriptorProxy
+    from typing_extensions import TypeGuard  # py310
     from typing_extensions import dataclass_transform as dataclass_transform  # py311
 
     from ._signal import SignalInstance
@@ -109,8 +107,8 @@ def no_class_attributes() -> Iterator[None]:  # pragma: no cover
 if not PYDANTIC_V1:
 
     def _get_defaults(
-        obj: Union[pydantic.BaseModel, Type[pydantic.BaseModel]],
-    ) -> Dict[str, Any]:
+        obj: Union[pydantic.BaseModel, type[pydantic.BaseModel]],
+    ) -> dict[str, Any]:
         """Get possibly nested default values for a Model object."""
         dflt = {}
         for k, v in obj.model_fields.items():
@@ -127,16 +125,25 @@ if not PYDANTIC_V1:
     def _get_config(cls: pydantic.BaseModel) -> "ConfigDict":
         return cls.model_config
 
-    def _get_fields(cls: pydantic.BaseModel) -> Dict[str, pydantic.fields.FieldInfo]:
+    def _get_fields(cls: pydantic.BaseModel) -> dict[str, pydantic.fields.FieldInfo]:
         return cls.model_fields
 
     def _model_dump(obj: pydantic.BaseModel) -> dict:
         return obj.model_dump()
 
+    def _is_pydantic_descriptor_proxy(obj: Any) -> "TypeGuard[PydanticDescriptorProxy]":
+        if (
+            type(obj).__module__.startswith("pydantic")
+            and type(obj).__name__ == "PydanticDescriptorProxy"
+            and isinstance(getattr(obj, "wrapped", None), property)
+        ):
+            return True
+        return False
+
 else:
 
     @no_type_check
-    def _get_defaults(obj: pydantic.BaseModel) -> Dict[str, Any]:
+    def _get_defaults(obj: pydantic.BaseModel) -> dict[str, Any]:
         """Get possibly nested default values for a Model object."""
         dflt = {}
         for k, v in obj.__fields__.items():
@@ -158,11 +165,11 @@ else:
         return GetAttrAsItem(cls.__config__)
 
     class FieldInfo(NamedTuple):
-        annotation: Union[Type[Any], None]
+        annotation: Union[type[Any], None]
         frozen: Union[bool, None]
 
     @no_type_check
-    def _get_fields(cls: type) -> Dict[str, FieldInfo]:
+    def _get_fields(cls: type) -> dict[str, FieldInfo]:
         return {
             k: FieldInfo(annotation=f.type_, frozen=not f.field_info.allow_mutation)
             for k, f in cls.__fields__.items()
@@ -171,6 +178,9 @@ else:
     def _model_dump(obj: pydantic.BaseModel) -> dict:
         return obj.dict()
 
+    def _is_pydantic_descriptor_proxy(obj: Any) -> "TypeGuard[PydanticDescriptorProxy]":
+        return False
+
 
 class ComparisonDelayer:
     """Context that delays before/after comparisons until exit."""
@@ -200,7 +210,7 @@ class EventedMetaclass(pydantic_main.ModelMetaclass):
     when each instance of an ``EventedModel`` is instantiated).
     """
 
-    __property_setters__: Dict[str, property]
+    __property_setters__: dict[str, property]
 
     @no_type_check
     def __new__(
@@ -259,10 +269,14 @@ class EventedMetaclass(pydantic_main.ModelMetaclass):
         # in EventedModel.__setattr__
         cls.__property_setters__ = {}
         if allow_props:
+            # inherit property setters from base classes
             for b in reversed(cls.__bases__):
                 if hasattr(b, "__property_setters__"):
                     cls.__property_setters__.update(b.__property_setters__)
+            # add property setters from this class
             for key, attr in namespace.items():
+                if _is_pydantic_descriptor_proxy(attr):
+                    attr = attr.wrapped
                 if isinstance(attr, property) and attr.fset is not None:
                     cls.__property_setters__[key] = attr
                     recursion = emission_map.get(key, default_strategy)
@@ -290,7 +304,7 @@ class EventedMetaclass(pydantic_main.ModelMetaclass):
 
 def _get_field_dependents(
     cls: "EventedMetaclass", model_config: dict, model_fields: dict
-) -> Dict[str, Set[str]]:
+) -> dict[str, set[str]]:
     """Return mapping of field name -> dependent set of property names.
 
     Dependencies may be declared in the Model Config to emit an event
@@ -312,9 +326,9 @@ def _get_field_dependents(
                 self.a, self.b = val
 
             class Config:
-                property_dependencies={'c': ['a', 'b']}
+                field_dependencies={'c': ['a', 'b']}
     """
-    deps: Dict[str, Set[str]] = {}
+    deps: dict[str, set[str]] = {}
 
     cfg_deps = model_config.get(FIELD_DEPENDENCIES, {})  # sourcery skip
     if not cfg_deps:
@@ -330,12 +344,12 @@ def _get_field_dependents(
     if cfg_deps:
         if not isinstance(cfg_deps, dict):  # pragma: no cover
             raise TypeError(
-                f"Config property_dependencies must be a dict, not {cfg_deps!r}"
+                f"Config field_dependencies must be a dict, not {cfg_deps!r}"
             )
         for prop, fields in cfg_deps.items():
             if prop not in {*model_fields, *cls.__property_setters__}:
                 raise ValueError(
-                    "Fields with dependencies must be fields or property.setters."
+                    "Fields with dependencies must be fields or property.setters. "
                     f"{prop!r} is not."
                 )
             for field in fields:
@@ -345,7 +359,7 @@ def _get_field_dependents(
                     )
                 deps.setdefault(field, set()).add(prop)
     if model_config.get(GUESS_PROPERTY_DEPENDENCIES, False):
-        # if property_dependencies haven't been explicitly defined, we can glean
+        # if field_dependencies haven't been explicitly defined, we can glean
         # them from the property.fget code object:
         # SKIP THIS MAGIC FOR NOW?
         for prop, setter in cls.__property_setters__.items():
@@ -383,7 +397,7 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
        one of the model fields it depends on is mutated you must set one of the
        following options in the `Config`:
 
-        - `property_dependencies` may be a `Dict[str, List[str]]`, where the
+        - `field_dependencies` may be a `Dict[str, List[str]]`, where the
           keys are the names of properties, and the values are a list of field names
           (strings) that the property depends on for its value
         - `guess_property_dependencies` may be set to `True` to "guess" property
@@ -446,15 +460,15 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
     _events: ClassVar[SignalGroup] = PrivateAttr()
 
     # mapping of name -> property obj for methods that are property setters
-    __property_setters__: ClassVar[Dict[str, property]]
+    __property_setters__: ClassVar[dict[str, property]]
     # mapping of field name -> dependent set of property names
     # when field is changed, an event for dependent properties will be emitted.
-    __field_dependents__: ClassVar[Dict[str, Set[str]]]
-    __eq_operators__: ClassVar[Dict[str, "EqOperator"]]
+    __field_dependents__: ClassVar[dict[str, set[str]]]
+    __eq_operators__: ClassVar[dict[str, "EqOperator"]]
     __slots__ = {"__weakref__"}
-    __signal_group__: ClassVar[Type[SignalGroup]]
-    _changes_queue: Dict[str, Any] = PrivateAttr(default_factory=dict)
-    _primary_changes: Set[str] = PrivateAttr(default_factory=set)
+    __signal_group__: ClassVar[type[SignalGroup]]
+    _changes_queue: dict[str, Any] = PrivateAttr(default_factory=dict)
+    _primary_changes: set[str] = PrivateAttr(default_factory=set)
     _delay_check_semaphore: int = PrivateAttr(0)
 
     if PYDANTIC_V1:
@@ -478,7 +492,7 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
         return self._events
 
     @property
-    def _defaults(self) -> Dict[str, Any]:
+    def _defaults(self) -> dict[str, Any]:
         return _get_defaults(self)
 
     def __eq__(self, other: Any) -> bool:
@@ -679,7 +693,7 @@ class EventedModel(pydantic.BaseModel, metaclass=EventedMetaclass):
 
         @classmethod
         @contextmanager
-        def enums_as_values(
+        def enums_as_values(  # type: ignore [misc] # Incompatible redefinition
             cls, as_values: bool = True
         ) -> Iterator[None]:  # pragma: no cover
             """Temporarily override how enums are retrieved.
